ytree\.arbor\.tree\_node\_selector\.TreeNodeSelector
====================================================

.. currentmodule:: ytree.arbor.tree_node_selector

.. autoclass:: TreeNodeSelector

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TreeNodeSelector.__init__
   
   

   
   
   